@@ -52,7 +52,7 @@ class MatchingType(Enum):
 
 
 class TestCase:
-    def __init__(self, input="", output="", name="", explanation="", matchingtype=MatchingType.flexible):
+    def __init__(self, input="", output="", name="", explanation="", matchingtype=MatchingType.flexible, sample=False):
         self.name = name
         self.input = input
         self.output = output
@@ -61,7 +61,7 @@ class TestCase:
         self.input_size = self.output_size = 0
         self.input_hash = self.output_hash = ''
         self.explanation = explanation
-        self.sample = False
+        self.sample = sample
         self.score = 0
 
     def __str__(self):
@@ -86,6 +86,7 @@ class Problem:
     def __init__(self, name=""):
         self.src_id = ""
         self.translations = {}
+        self.src = ""
         self.src_url = ""
         self.src_name = ""
         self.src_status_url = ""
@@ -103,6 +104,7 @@ class Problem:
         self.statement = self.src_id = ""
         self.statement_format = "markdown"
         self.statement_language = "vi"
+        self.code_stubs = {}
         self.input_format = self.constraints = self.output_format = ""
         self.judge_mode = JudgeMode.oj
         self.xp = 100
@@ -129,8 +131,8 @@ class Problem:
         self.public_test_cases = False
         self.public_solutions = False
         self.languages = []
-        self.solutions = []  # list of solution for each language
-        self.testcase_generators = []  # [{"lang"="", "code"=".."}]
+        self.solutions = []  # list of solution for each language [{"lang"="", "code"=".."}]
+        self.testcase_generators = []
         self.hints = []  # list of hint for each language
         self.track = None # hackerrank specific
         self.resource_files = []
