@@ -215,7 +215,12 @@ class UCode:
 
             if ques['solutions']:
                 sol = json.loads(ques['solutions'])
-                sol = sol.get('text')
+                sol = sol.get('text').strip()
+                if sol.startswith('```') and sol.endswith('```'):
+                    sol = "\n".join(sol.splitlines()[1:-1])
+
+                sol += "\n"
+
                 if sol:
                     if "#include" in sol:
                         lang = "cpp"
@@ -920,7 +925,8 @@ UX/UI	12/11/2020	BB #19: How to use Teko Design System for PO an BA	Trần Thàn
 
 def test_get_question():
     env, domain = "prod", "ucode.vn"
-    question_id = 44242
+    # question_id = 44242
+    question_id = 97526
 
     ucode = UCode(env=env, domain=domain)
 
@@ -978,11 +984,11 @@ if __name__ == "__main__":
     # create_problems_to_lesson_ucode("prod", domain="teko.ugrow.vn")
     # create_problems_to_lesson_ucode("prod")
 
-    # test_get_question()
+    test_get_question()
     # test_get_questions_from_quiz()
     # test_get_course_curriculum()
 
-    add_to_daily_challenge()
+    # add_to_daily_challenge()
 
     # create_problem("dev")
     # create_problem("prod", domain="teko.ugrow.vn")
